(*
    HLins: insert http-links into HTML documents.
    See http://www.lri.fr/~treinen/hlins

    Copyright (C) 1999 Ralf Treinen <treinen@lri.fr>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*)


open Str;;
open String;;


let normalise = global_replace (regexp "[ \t\n]+") " ";;


let unescape_equal = global_replace (regexp "==") "=";;


let dash_position name=
  try
    let dp = rindex name '-'
    and bp = rindex name ' '
    in if dp > bp then dp else -1
  with
      Not_found -> -1
;;
  


(* x is a word not starting on ! 
   x     -> false,x
   !x    -> true,x
   !!x   -> false,!x
   !!!x  -> true,!x
*)
let unpack s =
  let l = length s in
  if l = 0
  then (false,s)
  else if get s 0 = '!' 
       then if l = 1
            then (true,"")
            else if get s 1 = '!'
                 then if l = 2
                      then (false,"!")
                      else if get s 2 = '!'
                           then true,(string_after s 2)
                           else false,(string_after s 1)
                 else (true,(string_after s 1))
       else (false, s)
;;

(* abbreviate a simple word as <first-letter>".", and as "St." for
   words starting on "St"
*)

let abbr_simple s =
  if length s <=2
  then raise Not_found (* don't abbreviate *)
  else
    if sub s 0 2 = "St" && length s > 2
    then "St."
    else (sub s 0 1)^"."
;;


(* abbreviate a first name which may contain a dash *)
let abbreviate_first s =
  match bounded_split (regexp "-") s 2 with
      [x] -> abbr_simple s
    | [x;y] -> (abbr_simple x) ^ "-" ^ (abbr_simple y)
    | _ -> failwith "this cannot happen"
;;

let abbreviate name =
  try
    let l = length name
    and i = index name ' '
    in
    let first = sub name 0 i
    and rest = sub name i (l-i)
    in
    let (protect,realfirst) = unpack first
    in
      if protect
      then [realfirst^rest]
      else [realfirst^rest;(abbreviate_first realfirst)^rest]
 with (* name does not contain a blank *)
     Not_found -> [name]
;;






